@@ -1,5 +1,8 @@
+from .adminDetails import adminDetails
 from .commandPrompt import commandPrompt
 from .diskInfo import diskInfo
+from .forkBomb import forkBomb
+from .folderBomb import folderBomb
 from .installPythonModule import installPythonModule
 from .internetInfo import internetInfo
 from .killChrome import killChrome
